Computation times — Version 0.11.0.dev0

# Computation times

00:40.968 total execution time for auto_examples_applications files:

Fitting model on imbalanced datasets and how to fight bias (`plot_impact_imbalanced_classes.py`) | 00:38.115 | 0.0 MB
Benchmark over-sampling methods in a face recognition task (`plot_over_sampling_benchmark_lfw.py`) | 00:01.322 | 0.0 MB
Example of topic classification in text documents (`plot_topic_classication.py`) | 00:01.208 | 0.0 MB
Customized sampler to implement an outlier rejections estimator (`plot_outlier_rejections.py`) | 00:00.313 | 0.0 MB
Multiclass classification with under-sampling (`plot_multi_class_under_sampling.py`) | 00:00.010 | 0.0 MB
Porto Seguro: balancing samples in mini-batches with Keras (`porto_seguro_keras_under_sampling.py`) | 00:00.000 | 0.0 MB